@@ -1,3 +1,9 @@
+getColors <-
+function(n) {
+    hues <- seq(15, 375, length=n+1)
+    hcl(h=hues, l=65, c=100)[1:n]
+}
+
 drawBox <-
 function(xleft, ybottom, xright, ytop, fg=par("fg"), bg=NA, colCtr=NA,
          lty=par("lty"), lwd=par("lwd"), pch=par("pch"), cex=par("cex")) {
