@@ -12,9 +12,9 @@ function(xy) {
     rowN <- (n-1):1                        # number of rows in dMat
 
     ## find point pair with the maximum pairwise distance
-    ind <- which.max(dMat)                 # linear index
-    i   <- sum(cumsum(rowN) < ind) + 1     # first point
-    j   <- n - (sum(rowN[1:i]) - ind)      # second point
+    idx <- which.max(as.matrix(dMat))[1]   # maximum distance
+    i   <- (idx-1) %/% n+1                 # column -> point 1
+    j   <- (idx-1) %%  n+1                 # row    -> point 2
 
     return(list(d=max(dMat), idx=c(i, j)))
 }
